==> worlds_celeste_open_world-1.0.5.tar.gz: worlds_celeste_open_world-1.0.5/src/worlds/celeste_open_world/docs/en_Celeste (Open World).md <==
# Celeste Open World

## What is this game?

**Celeste (Open World)** is a  Randomizer for the original Celeste. In this acclaimed platformer created by ExOK Games, you control Madeline as she attempts to climb the titular mountain, meeting friends and obstacles along the way.
This randomizer takes an "Open World" approach. All of your active areas are open to you from the start. Progression is found in unlocking the ability to interact with various objects in the areas, such as springs, traffic blocks, feathers, and many more. One area can be selected as your "Goal Area", requiring you to clear that area before you can access the Epilogue and finish the game. Additionally, you can be required to receive a customizable amount of `Strawberry` items to access the Epilogue and optionally to access your Goal Area as well.
There are a variety of progression, location, and aesthetic options available. Please be safe on the climb.

## Where is the options page?

The [player options page for this game](../player-options) contains all the options you need to configure and export a config file.

## What does randomization do to this game?

By default, the Prologue, the A-Side levels for Chapters 1-7, and the Epilogue are included in the randomizer. Using options, B- and C-Sides can also be included, as can the Core and Farewell chapters. One level is chosen via an option to be the "Goal Area". Obtaining the required amount of Strawberry items from the multiworld and clearing this Goal Area will grant access to the Epilogue and the Credits, which is the goal of the randomizer.

## What items get shuffled?

The main collectable in this game is Strawberries, which you must collect to complete the game.

16 Crystal Heart items are included as filler items (Heart Gates are disabled in this mod). Any additional space in the item pool is filled by Raspberries, which do nothing, and Traps.

The following interactable items are included in the item pool, so long as any active level includes them:
- Springs
- Dash Refills
- Traffic Blocks
- Pink Cassette Blocks
- Blue Cassette Blocks
- Dream Blocks
- Coins
- Strawberry Seeds
- Sinking Platforms
- Moving Platforms
- Blue Clouds
- Pink Clouds
- Blue Boosters
- Red Boosters
- Move Blocks
- White Block
- Swap Blocks
- Dash Switches
- Torches
- Theo Crystal
- Feathers
- Bumpers
- Kevins
- Badeline Boosters
- Fire and Ice Balls
- Core Toggles
- Core Blocks
- Pufferfish
- Jellyfish
- Double Dash Refills
- Breaker Boxes
- Yellow Cassette Blocks
- Green Cassette Blocks
- Bird

Additionally, the following items can optionally be included in the Item Pool:
- Keys
- Checkpoints
- Summit Gems
- One Cassette per active level

Finally, the following Traps can be optionally included in the Item Pool:
- Bald Trap
- Literature Trap
- Stun Trap
- Invisible Trap
- Fast Trap
- Slow Trap
- Ice Trap
- Reverse Trap
- Screen Flip Trap
- Laughter Trap
- Hiccup Trap
- Zoom Trap

## What locations get shuffled?

By default, the locations in Celeste (Open World) which can contain items are:
- Level Clears
- Strawberries
- Crystal Hearts
- Cassettes

Additionally, the following locations can optionally be included in the Location Pool:
- Golden Strawberries
- Keys
- Checkpoints
- Summit Gems
- Cars
- Binoculars
- Rooms

## How can I get started?

To get started playing Celeste (Open World) in Archipelago, [go to the setup guide for this game](../../../tutorial/Celeste%20(Open%20World)/guide/en)

==> worlds_celeste_open_world-1.0.6.tar.gz: worlds_celeste_open_world-1.0.6/src/worlds/celeste_open_world/docs/en_Celeste (Open World).md <==
# Celeste Open World

## What is this game?

**Celeste (Open World)** is a  Randomizer for the original Celeste. In this acclaimed platformer created by ExOK Games, you control Madeline as she attempts to climb the titular mountain, meeting friends and obstacles along the way.
This randomizer takes an "Open World" approach. All of your active areas are open to you from the start. Progression is found in unlocking the ability to interact with various objects in the areas, such as springs, traffic blocks, feathers, and many more. One area can be selected as your "Goal Area", requiring you to clear that area before you can access the Epilogue and finish the game. Additionally, you can be required to receive a customizable amount of `Strawberry` items to access the Epilogue and optionally to access your Goal Area as well.
There are a variety of progression, location, and aesthetic options available. Please be safe on the climb.

## Where is the options page?

The [player options page for this game](../player-options) contains all the options you need to configure and export a config file.

## What does randomization do to this game?

By default, the Prologue, the A-Side levels for Chapters 1-7, and the Epilogue are included in the randomizer. Using options, B- and C-Sides can also be included, as can the Core and Farewell chapters. One level is chosen via an option to be the "Goal Area". Obtaining the required amount of Strawberry items from the multiworld and clearing this Goal Area will grant access to the Epilogue and the Credits, which is the goal of the randomizer.

## What items get shuffled?

The main collectable in this game is Strawberries, which you must collect to complete the game.

16 Crystal Heart items are included as filler items (Heart Gates are disabled in this mod). Any additional space in the item pool is filled by Raspberries, which do nothing, and Traps.

The following interactable items are included in the item pool, so long as any active level includes them:
- Springs
- Dash Refills
- Traffic Blocks
- Pink Cassette Blocks
- Blue Cassette Blocks
- Dream Blocks
- Coins
- Strawberry Seeds
- Sinking Platforms
- Moving Platforms
- Blue Clouds
- Pink Clouds
- Blue Boosters
- Red Boosters
- Move Blocks
- White Block
- Swap Blocks
- Dash Switches
- Torches
- Theo Crystal
- Feathers
- Bumpers
- Kevins
- Badeline Boosters
- Fire and Ice Balls
- Core Toggles
- Core Blocks
- Pufferfish
- Jellyfish
- Double Dash Refills
- Breaker Boxes
- Yellow Cassette Blocks
- Green Cassette Blocks
- Bird

Additionally, the following items can optionally be included in the Item Pool:
- Keys
- Checkpoints
- Summit Gems
- One Cassette per active level

Finally, the following Traps can be optionally included in the Item Pool:
- Bald Trap
- Literature Trap
- Stun Trap
- Invisible Trap
- Fast Trap
- Slow Trap
- Ice Trap
- Reverse Trap
- Screen Flip Trap
- Laughter Trap
- Hiccup Trap
- Zoom Trap

## What locations get shuffled?

By default, the locations in Celeste (Open World) which can contain items are:
- Level Clears
- Strawberries
- Crystal Hearts
- Cassettes

Additionally, the following locations can optionally be included in the Location Pool:
- Golden Strawberries
- Keys
- Checkpoints
- Summit Gems
- Cars
- Binoculars
- Rooms

## How can I get started?

To get started playing Celeste (Open World) in Archipelago, [go to the setup guide for this game](/tutorial/Celeste%20%28Open%20World%29/guide_en)
